import os
import tempfile
import re
from copy import copy

from rst2pdf.basenodehandler import NodeHandler

import docutils.nodes
from rst2pdf.oddeven_directive import OddEvenNode
import reportlab

from rst2pdf.aafigure_directive import Aanode

from rst2pdf.log import log, nodeid
from rst2pdf.utils import log, parseRaw, parseHTML
from reportlab.platypus import Paragraph, TableStyle
from reportlab.lib.units import cm
from reportlab.lib.enums import TA_LEFT, TA_CENTER, TA_RIGHT
from rst2pdf.flowables import Table, DelayedTable, SplitTable, Heading, \
              MyIndenter, MyTableOfContents, MySpacer, \
              Separation, BoxedContainer, BoundByWidth, \
              MyPageBreak, Reference, tablepadding, OddEven, \
              XPreformatted

from rst2pdf.opt_imports import wordaxe, Paragraph, ParagraphStyle

from rst2pdf.genelements import HandleFigure

def install(createpdf, options):
    #options.header='###Section###'
    #options.footer='###Title### - ###Page###/###Total###'
    path_style = os.path.join(os.path.split(__file__)[0], 'pptmecapack.style')
    options.style = [path_style,]
 


class HandleAdmonition(NodeHandler, docutils.nodes.attention,
                docutils.nodes.caution, docutils.nodes.danger,
                docutils.nodes.error, docutils.nodes.hint,
                docutils.nodes.important, docutils.nodes.note,
                docutils.nodes.tip, docutils.nodes.warning,
                docutils.nodes.Admonition):

    def gather_elements(self, client, node, style):
        if node.children and isinstance(node.children[0], docutils.nodes.title):
            title=[]
        else:
            title= [Paragraph(client.text_for_label(node.tagname, style),
                style=client.styles['%s-heading'%node.tagname])]
        #ADD BY FAO        
        #rows=title + client.gather_elements(node, style=style)
        rows = client.gather_elements(node, style=style)
        #END ADD BY FAO
        st=client.styles[node.tagname]
        if 'commands' in dir(st):
            t_style = TableStyle(st.commands)
        else:
            t_style = TableStyle()
        t_style.add("ROWBACKGROUNDS", [0, 0], [-1, -1],[st.backColor])
        #ADD BY FAO
        #t_style.add("BOX", [ 0, 0 ], [ -1, -1 ], st.borderWidth , st.borderColor)
        path_icon = os.path.join(os.path.split(__file__)[0], 'admonition')
        t_style.add("VALIGN",[ 0, 0 ], [ -1, -1 ], 'CENTER')
        node_img = docutils.nodes.image(uri='%s/%s.png' % (path_icon, node.tagname) ,align='CENTER', scale='100')
        node_fig = docutils.nodes.figure(rawsource='')
        node_fig.append(node_img)
        img = HandleFigure().gather_elements(client,node_fig, style)
        if client.splittables:
            node.elements = [MySpacer(0,st.spaceBefore),
                                SplitTable([[img,rows]],
                                style=t_style,
                                colWidths=[58,None],
                                padding=st.borderPadding),
                                MySpacer(0,st.spaceAfter)]
        else:
            padding, p1, p2, p3, p4=tablepadding(padding=st.borderPadding)
            t_style.add(*p1)
            t_style.add(*p2)
            t_style.add(*p3)
            t_style.add(*p4)
            node.elements = [MySpacer(0,st.spaceBefore),
                                DelayedTable([[img,rows]],
                                style=t_style,
                                colWidths=[58, None]),
                                MySpacer(0,st.spaceAfter)]
        #END AD BY FAO
        return node.elements




